%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% File name: MeasurementMain.m
%
% Description: Real time measurement loop for identification measurements
%
% Inputs: Input signal, sampling period and output dimension. 
%
% Outputs: Measured data.
%
% Author and copyright: Torbjrn Wigren
%                       Systems and Control
%                       Department of Information Technology
%                       Uppsala University
%                       Uppsala
%                       Sweden
%
% Revision log: Created 2004-01-08.
%
% Firm revision: revision 1.0, 2004-12-23.
%					  revision 2.0, 2005-08-24 (no changes).
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

NumberOfMeasurements=size(u,2);
y=zeros(yDim,NumberOfMeasurements);
SamplingInstances=zeros(1,NumberOfMeasurements);

%
% Measurement loop
%

t0=clock;
for measurement=1:NumberOfMeasurements
   
   %
   % Get samplinginstance
   %
   
   SamplingInstances(1,measurement)=etime(clock,t0);
   
   %
   % Read output from AD
   %
   
   y(1,measurement)=proc_AD(0);
   y(2,measurement)=proc_AD(1);
   [SamplingInstances(1,measurement) u(1,measurement) y(1,measurement) y(2,measurement)]
	[SamplingInstances(1,measurement) u(1,measurement)]

   %
   % Write input to DA 
   %
   
%   proc_DA(0,u(1,measurement));
   
   %
   % Get elapsed time
   %
   
   elapsedTime=etime(clock,t0);
   
   %
   % Wait until the next sample is to be read
   %
   
   while elapsedTime<measurement*Ts;
      elapsedTime=etime(clock,t0);
   end
   
   %
   % Ready for next measurement
   %
   
end
