%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% File name: SimulateModelOutput.m
%
% Description: Simulates the model output, using parameters
%              obtained at the end of the run. Also computes
%              the corresponding residuals.
%
% Inputs: Input signals, estimated parameters as well as the
%         system output signals.
%
% Outputs: Simulated output signals and corresponding residuals.
%
% Author and copyright: Torbjrn Wigren
%                       Systems and Control
%                       Department of Information Technology
%                       Uppsala University
%                       Uppsala
%                       Sweden
%
% Revision log: Created 2003-06-05.
%
% Firm revision: revision 1.0, 2004-12-23.
%		 revision 2.0, 2005-08-24 (no changes).
%                revision 3.0, 2010-09-06.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%
% Integrate
%

% Apply an Euler forward or midpoint method, depending on the 
% scheme used in the RPEM.

x_ms=zeros(nx,N+1);
y_ms=zeros(ny,N+1);
x_ms(:,1)=x_m_0;
percentReady=0;
for t=SamplingInstances(1,1):Ts:SamplingInstances(1,N-1)
    if round(t*100/N/Ts)>percentReady
        percentReady=round(t*100/N/Ts);
    end
    k=round(t/Ts); % Sampling index into matrices
    if strcmp(method,'Euler')
        x_ms(:,k+1)=x_ms(:,k)+Ts*scalingTs*f_m(x_ms(:,k),u(:,k)...
            ,theta,allIndices);
    elseif strcmp(method,'midpoint')
        x_ms(:,k+1)=x_ms(:,k)+Ts*scalingTs*f_m(x_ms(:,k)+0.5*...
            scalingTs*Ts*f_m(x_ms(:,k),u(:,k),theta,allIndices)...
            ,u(:,k),theta,allIndices);
    end
    y_ms(:,k)=h_m(x_ms(:,k),u(:,k));
end
