%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% File name: differentiateY.m
%
% Description: Approximation of state vector obtained by
%              numerical differentiation of the output signal
%
% Inputs: y - measured output
%         oldXi - previous approximation of state vector
%         Ts - sampling period
%
% Outputs: newXi - numerically estimated state vector
%
% Author and copyright: Linda Brus
%                       Systems and Control
%                       Department of Information Technology
%                       Uppsala University
%                       Uppsala
%                       Sweden
%
% Revision log: Created 2005-05-09.
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [newXi]=differentiateY(y,oldXi,Ts)

nx=size(oldXi,1);
newXi(1,1)=y;
for i=2:nx
   newXi(i,1)=(newXi(i-1,1)-oldXi(i-1,1))/Ts;
end;


